#
# spec file for package libXmu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXmu
Version:        1.2.1
Release:        1.3
Summary:        Miscellaneous utility routines for X
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXmu
#Git-Web:       http://cgit.freedesktop.org/xorg/lib/libXmu/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtrans)

%description
The Xmu Library is a collection of miscellaneous (some might say random)
utility functions that have been useful in building various applications
and widgets. This library is required by the Athena Widgets.

%package -n libXmu6
Summary:        Miscellaneous utility routines for X
# O/P added for 12.2
Group:          System/Libraries
Provides:       xorg-x11-libXmu = 7.6_%version-%release
Obsoletes:      xorg-x11-libXmu < 7.6_%version-%release
Requires:       xbitmaps

%description -n libXmu6
The Xmu library is a collection of miscellaneous (some might say random)
utility functions that have been useful in building various applications
and widgets, specifically the Athena Widgets.

%package -n libXmuu1
Summary:        More miscellaneous utility routines for X
Group:          System/Libraries

%description -n libXmuu1
The Xmu/Xmuu libraries are a collection of miscellaneous (some might
say random) utility functions that have been useful in building
various applications and widgets.

%package devel
Summary:        Development files for the X Miscellaneous Utility Libraries
Group:          Development/Libraries/C and C++
Requires:       libXmu6 = %version
Requires:       libXmuu1 = %version
# O/P added for 12.2
Provides:       xorg-x11-libXmu-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXmu-devel < 7.6_%version-%release
Requires:       xbitmaps-devel

%description devel
The Xmu/Xmuu libraries are a collection of miscellaneous (some might
say random) utility functions that have been useful in building
various applications and widgets.

This package contains the development headers for the library found
in libXmu6 and libXmuu1.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post   -n libXmu6 -p /sbin/ldconfig

%postun -n libXmu6 -p /sbin/ldconfig

%post   -n libXmuu1 -p /sbin/ldconfig

%postun -n libXmuu1 -p /sbin/ldconfig

%files -n libXmu6
%defattr(-,root,root)
%_libdir/libXmu.so.6*

%files -n libXmuu1
%defattr(-,root,root)
%_libdir/libXmuu.so.1*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXmu*.so
%_libdir/pkgconfig/xmu*.pc
%_docdir/%name

%changelog
* Wed Apr 17 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.1
  * test: Add missing setjmp()
  * test: Add prototype for Xmureallocarray to silence warning
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * This release raises the minimum version of libXt required to 1.1.0
    (released in 2011), and for those builders who need to regenerate
    the autoconf files, raises the minimum version of autoconf required
    to 2.70 (released in 2020).
* Tue Oct 18 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.4
  This release includes two notable changes to XmuConvertStandardSelection():
  1) It no longer supports XA_IP_ADDRESS, which only supported IPv4 addresses
  and simply provided the output of gethostbyname() on the local hostname.
  2) XA_OWNER_OS no longer reports "BSD" for any Unix-like OS (including Linux)
  that it hadn't been coded to handle, instead relying on uname() where
  available to provide the OS name.
  The lack of bug reports about the previously misleading output for these
  suggests they're not widely used, with codesearch.debian.net only finding
  matches in libXmu and the rust bindings to libXmu, and not any consumers
  of these interfaces.
* Thu Mar 21 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.3
  * This minor maintenance release includes some small bug fixes,
    build configuration improvements and janitorial cleanups.
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.1.2:
  + Add missing copyright notices to COPYING file.
  + Preserve constness when casting const pointers in various
    functions.
  + Fix a const issue.
  + autogen.sh: Implement GNOME Build API.
  + configure: Remove AM_MAINTAINER_MODE.
  + Remove unused DECnet ("DNETCONN") code from
    XmuConvertStandardSelection.
* Thu Aug 29 2013 sndirsch@suse.com
- added requires to xbitmaps/-devel packages (bnc#836530)
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.1.1:
  + Cleanups of code that causes compiler warnings
  + Improvements to the documentation
  + Build configuration improvements
* Sat Feb 11 2012 jengelh@medozas.de
- Rename xorg-x11-libXmu to libXmu and utilize shlib policy
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Wed Dec  1 2010 jslaby@suse.de
- revert 'export only public API symbols'
  it breaks xclock, xterm and others
* Tue Nov 30 2010 cristian.rodriguez@opensuse.org
- export only public API symbols
- disable silent rules, defeat the purpose of post build checks
* Sat Oct 30 2010 sndirsch@novell.com
- libXmu 1.1.0
  * API documentation for this library has been added in this
    release in the docs directory in DocBook format.  If xmlto is
    installed, it will be converted to supported formats and
    installed in $(docdir) unless --disable-docs is passed to
    configure.
    This release also includes the usual recent set of build
    configuration improvements and janitorial cleanups.
* Sun Apr  4 2010 sndirsch@suse.de
- libXmu 1.0.5
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 15 2008 sndirsch@suse.de
- update to release 1.0.4
  * Coverity #52: Dead code in get_os_name()
* Tue Jan  1 2008 crrodriguez@suse.de
- fix library-without-ldconfig-* error
- add missing PreReq coreutils
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Wed Nov  8 2006 sndirsch@suse.de
- update to release 1.0.3
  * Due to some confusion, libXmu 1.0.2 was actually rolled and
    released twice. Thus, /releases/development/7.2-RC1/lib/
    contains the libXmu-1.0.2.tar.* that ajax released a while
    ago, and /releases/individual/lib/ contains the original ones.
    libXmu 1.0.3 has no changes from 1.0.2, it's just to clear the
    versioning confusion.  Thanks to Tilman again for pointing this
    out.
* Sat Oct 14 2006 sndirsch@suse.de
- updated to X.org 7.2RC1
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Thu Jun 22 2006 sndirsch@suse.de
- created package
